import typing
import collections.abc
import typing_extensions
import bgui.widget

class ProgressBar(bgui.widget.Widget):
    """A solid progress bar.
    Controlled via the 'percent' property which assumes percent as a 0-1 floating point number.
    """

    children: typing.Any
    on_active: typing.Any
    on_click: typing.Any
    on_hover: typing.Any
    on_mouse_enter: typing.Any
    on_mouse_exit: typing.Any
    on_release: typing.Any
    parent: typing.Any
    percent: typing.Any
    position: typing.Any
    size: typing.Any
    system: typing.Any
    theme_options: typing.Any
    theme_section: typing.Any



import typing
import collections.abc
import typing_extensions

def get_all_referenced_ids(id, ref_map):
    """Return a set of IDs directly or indirectly referenced by id."""

def get_id_reference_map():
    """Return a dictionary of direct datablock references for every datablock in the blend file."""

def recursive_get_referenced_ids(ref_map, id, referenced_ids, visited):
    """Recursively populate referenced_ids with IDs referenced by id."""
